@@ -1,4 +1,4 @@
-//@line 39 "/home/karma/src/build/build/mail/extensions/newsblog/content/utils.js"
+//@line 40 "/mnt/Srcs/Thunderbird/build/mailnews/extensions/newsblog/content/utils.js"
 
 // Whether or not to dump debugging messages to the console.
 const DEBUG = false;
@@ -8,10 +8,13 @@ if (DEBUG)
 else
   debug = function() {}
 
-var rdf = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);
+Components.utils.import("resource://gre/modules/ISO8601DateUtils.jsm");
+var rdf = Components.classes["@mozilla.org/rdf/rdf-service;1"]
+                    .getService(Components.interfaces.nsIRDFService);
+var rsspref = Components.classes["@mozilla.org/preferences-service;1"]
+                        .getService(Components.interfaces.nsIPrefBranch);
 
-const RDF_NS = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
-const RDF_TYPE = rdf.GetResource(RDF_NS + "type");
+const RDF_TYPE = rdf.GetResource("http://www.w3.org/1999/02/22-rdf-syntax-ns#type");
 
 const RSS_NS = "http://purl.org/rss/1.0/";
 const RSS_CHANNEL = rdf.GetResource(RSS_NS + "channel");
@@ -33,6 +36,7 @@ const DC_LASTMODIFIED = rdf.GetResource(DC_NS + "lastModified");
 const DC_IDENTIFIER = rdf.GetResource(DC_NS + "identifier");
 
 const FZ_NS = "urn:forumzilla:";
+const FZ_ITEM_NS = "urn:feeditem:";
 const FZ_ROOT = rdf.GetResource(FZ_NS + "root");
 const FZ_FEEDS = rdf.GetResource(FZ_NS + "feeds");
 const FZ_FEED = rdf.GetResource(FZ_NS + "feed");
@@ -40,6 +44,7 @@ const FZ_QUICKMODE = rdf.GetResource(FZ_NS + "quickMode");
 const FZ_DESTFOLDER = rdf.GetResource(FZ_NS + "destFolder");
 const FZ_STORED = rdf.GetResource(FZ_NS + "stored");
 const FZ_VALID = rdf.GetResource(FZ_NS + "valid");
+const FZ_LAST_SEEN_TIMESTAMP = rdf.GetResource(FZ_NS + "last-seen-timestamp");
 
 const RDF_LITERAL_TRUE = rdf.GetLiteral("true");
 const RDF_LITERAL_FALSE = rdf.GetLiteral("false");
@@ -48,26 +53,34 @@ const RDF_LITERAL_FALSE = rdf.GetLiteral("false");
 const ATOM_03_NS = "http://purl.org/atom/ns#";
 const ATOM_IETF_NS = "http://www.w3.org/2005/Atom";
 
+// The approximate amount of time, specified in milliseconds, to leave an item in the
+// RDF cache after the item has dissappeared from feeds.
+// The delay is currently one day.
+const INVALID_ITEM_PURGE_DELAY = 24 * 60 * 60 * 1000;
+
 // XXX There's a containerutils in forumzilla.js that this should be merged with.
 var containerUtils = Components.classes["@mozilla.org/rdf/container-utils;1"]
                                .getService(Components.interfaces.nsIRDFContainerUtils);
 
-var fileHandler = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService)
-                            .getProtocolHandler("file").QueryInterface(Components.interfaces.nsIFileProtocolHandler);
+var fileHandler = Components.classes["@mozilla.org/network/io-service;1"]
+                            .getService(Components.interfaces.nsIIOService)
+                            .getProtocolHandler("file")
+                            .QueryInterface(Components.interfaces.nsIFileProtocolHandler);
 
-// helper routine that checks our subscriptions list array and returns true if the url 
-// is already in our list. This is used to prevent the user from subscribing to the same
-// feed multiple times for the same server...
+// Helper routine that checks our subscriptions list array and returns
+// true if the url is already in our list. This is used to prevent the
+// user from subscribing to the same feed multiple times for the same server...
 function feedAlreadyExists(aUrl, aServer)
 {
-  var feeds = getSubscriptionsList(aServer);
+  var ds = getSubscriptionsDS(aServer);
+  var feeds = getSubscriptionsList(aServer, ds);
   return feeds.IndexOf(rdf.GetResource(aUrl)) != -1;
 }
 
-function addFeed(url, title, destFolder) 
+function addFeed(url, title, destFolder)
 {
   var ds = getSubscriptionsDS(destFolder.server);
-  var feeds = getSubscriptionsList(destFolder.server);
+  var feeds = getSubscriptionsList(destFolder.server, ds);
 
   // Generate a unique ID for the feed.
   var id = url;
@@ -84,42 +97,87 @@ function addFeed(url, title, destFolder)
   ds.Assert(id, DC_IDENTIFIER, rdf.GetLiteral(url), true);
   if (title)
     ds.Assert(id, DC_TITLE, rdf.GetLiteral(title), true);
-	ds.Assert(id, FZ_DESTFOLDER, destFolder, true);
+  ds.Assert(id, FZ_DESTFOLDER, destFolder, true);
   ds = ds.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource);
   ds.Flush();
 }
 
-// updates the "feedUrl" property in the message database for the folder in question.
+function deleteFeed(aId, aServer)
+{
+  var feed = new Feed(aId, aServer);
+  var ds = getSubscriptionsDS(aServer);
 
-var kFeedUrlDelimiter = '|'; // the delimiter used to delimit feed urls in the msg folder database "feedUrl" property
+  if (feed && ds)
+  {
+    // remove the feed from the subscriptions ds
+    var feeds = getSubscriptionsList(aServer, ds);
+    var index = feeds.IndexOf(aId);
+    if (index != -1)
+      feeds.RemoveElementAt(index, false);
+
+    // remove the feed property string from the folder data base
+    var currentFolder = ds.GetTarget(aId, FZ_DESTFOLDER, true);
+    if (currentFolder)
+    {
+      var currentFolderURI = currentFolder.QueryInterface(Components.interfaces.nsIRDFResource).Value;
+      currentFolder = rdf.GetResource(currentFolderURI)
+                         .QueryInterface(Components.interfaces.nsIMsgFolder);
+
+      var feedUrl = ds.GetTarget(aId, DC_IDENTIFIER, true);
+      ds.Unassert(aId, DC_IDENTIFIER, feedUrl, true);
+
+      feedUrl = feedUrl ? feedUrl.QueryInterface(Components.interfaces.nsIRDFLiteral).Value : "";
+
+      updateFolderFeedUrl(currentFolder, feedUrl, true); // remove the old url
+    }
+
+    // Remove all assertions about the feed from the subscriptions database.
+    removeAssertions(ds, aId);
+    ds.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush(); // flush any changes
+
+    // Remove all assertions about items in the feed from the items database.
+    var itemds = getItemsDS(aServer);
+    feed.invalidateItems();
+    feed.removeInvalidItems();
+    itemds.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush(); // flush any changes
+  }
+}
+
+// Updates the "feedUrl" property in the message database for the folder
+// in question
+
+// The delimiter used to delimit feed urls in the msg folder database
+// "feedUrl" property
+var kFeedUrlDelimiter = '|';
 
 function updateFolderFeedUrl(aFolder, aFeedUrl, aRemoveUrl)
 {
-  var msgdb = aFolder.QueryInterface(Components.interfaces.nsIMsgFolder).getMsgDatabase(null);
+  var msgdb = aFolder.QueryInterface(Components.interfaces.nsIMsgFolder)
+                     .msgDatabase;
   var folderInfo = msgdb.dBFolderInfo;
-  var oldFeedUrl = folderInfo.getCharPtrProperty("feedUrl");
+  var oldFeedUrl = folderInfo.getCharProperty("feedUrl");
 
   if (aRemoveUrl)
-  { 
-    // remove our feed url string from the list of feed urls
+  {
+    // Remove our feed url string from the list of feed urls
     var newFeedUrl = oldFeedUrl.replace(kFeedUrlDelimiter + aFeedUrl, "");
-    folderInfo.setCharPtrProperty("feedUrl", newFeedUrl);
-  }  
-  else 
-    folderInfo.setCharPtrProperty("feedUrl", oldFeedUrl + kFeedUrlDelimiter + aFeedUrl);  
+    folderInfo.setCharProperty("feedUrl", newFeedUrl);
+  }
+  else
+    folderInfo.setCharProperty("feedUrl", oldFeedUrl + kFeedUrlDelimiter + aFeedUrl);
 
-  // commit the db to preserve our changes
+  // Commit the db to preserve our changes
   msgdb.Close(true);
 }
 
-function getNodeValue(node) 
+function getNodeValue(node)
 {
   if (node && node.textContent)
     return node.textContent;
-  else if (node && node.firstChild) 
+  else if (node && node.firstChild)
   {
     var ret = "";
-    for (var child = node.firstChild; child; child = child.nextSibling) 
+    for (var child = node.firstChild; child; child = child.nextSibling)
     {
       var value = getNodeValue(child);
       if (value)
@@ -133,27 +191,27 @@ function getNodeValue(node)
   return null;
 }
 
-function getRDFTargetValue(ds, source, property) 
+function getRDFTargetValue(ds, source, property)
 {
   var node = ds.GetTarget(source, property, true);
-  if (node) 
+  if (node)
   {
     try{
       node = node.QueryInterface(Components.interfaces.nsIRDFLiteral);
       if (node)
         return node.Value;
     }catch(e){
-      // if the RDF was bogus, do nothing. rethrow if it's some other problem
-      if(!((e instanceof Components.interfaces.nsIXPCException) 
-	    && (e.result==Components.results.NS_ERROR_NO_INTERFACE)))
+      // If the RDF was bogus, do nothing. Rethrow if it's some other problem
+      if (!((e instanceof Components.interfaces.nsIXPCException) &&
+            (e.result==Components.results.NS_ERROR_NO_INTERFACE)))
         throw e;
-    }	    
-    
+    }
+
   }
   return null;
 }
 
-function getSubscriptionsDS(server) 
+function getSubscriptionsDS(server)
 {
   var file = getSubscriptionsFile(server);
   var url = fileHandler.getURLSpecFromFile(file);
@@ -168,9 +226,8 @@ function getSubscriptionsDS(server)
   return ds;
 }
 
-function getSubscriptionsList(server) 
+function getSubscriptionsList(server, ds)
 {
-  var ds = getSubscriptionsDS(server);
   var list = ds.GetTarget(FZ_ROOT, FZ_FEEDS, true);
   //list = feeds.QueryInterface(Components.interfaces.nsIRDFContainer);
   list = list.QueryInterface(Components.interfaces.nsIRDFResource);
@@ -178,7 +235,7 @@ function getSubscriptionsList(server)
   return list;
 }
 
-function getSubscriptionsFile(server) 
+function getSubscriptionsFile(server)
 {
   server.QueryInterface(Components.interfaces.nsIRssIncomingServer);
   var file = server.subscriptionsDataSourcePath;
@@ -190,7 +247,33 @@ function getSubscriptionsFile(server)
   return file;
 }
 
-function createSubscriptionsFile(file) 
+// Generic get feed property, based on child value. Assumes 1 unique
+// child value with 1 unique parent, valid for feeds.rdf structure.
+function getParentTargetForChildResource(childResource, parentTarget, server)
+{
+  var ds = getSubscriptionsDS(server);
+  var childRes = rdf.GetResource(childResource);
+  var parent = null;
+
+  var arcsIn = ds.ArcLabelsIn(childRes);
+  while (arcsIn.hasMoreElements()){
+    var arc = arcsIn.getNext();
+    if (arc instanceof Components.interfaces.nsIRDFResource){
+      parent = ds.GetSource(arc, childRes, true);
+      parent = parent.QueryInterface(Components.interfaces.nsIRDFResource);
+      break;
+    }
+  }
+
+  if (parent) {
+    var resource = rdf.GetResource(parent.Value);
+    return ds.GetTarget(resource, parentTarget, true);
+  }
+
+  return null;
+}
+
+function createSubscriptionsFile(file)
 {
   file = new LocalFile(file, MODE_WRONLY | MODE_CREATE);
   file.write('\
@@ -209,7 +292,7 @@ function createSubscriptionsFile(file)
   file.close();
 }
 
-function getItemsDS(server) 
+function getItemsDS(server)
 {
   var file = getItemsFile(server);
   var url = fileHandler.getURLSpecFromFile(file);
@@ -227,13 +310,13 @@ function getItemsDS(server)
   return ds;
 }
 
-function getItemsFile(server) 
+function getItemsFile(server)
 {
   server.QueryInterface(Components.interfaces.nsIRssIncomingServer);
   var file = server.feedItemsDataSourcePath;
 
   // If the file doesn't exist, create it.
-  if (!file.exists()) 
+  if (!file.exists())
   {
     var newfile = new LocalFile(file, MODE_WRONLY | MODE_CREATE);
     newfile.write('\
@@ -248,16 +331,16 @@ function getItemsFile(server)
   return file;
 }
 
-function removeAssertions(ds, resource) 
+function removeAssertions(ds, resource)
 {
   var properties = ds.ArcLabelsOut(resource);
   var property;
-  while (properties.hasMoreElements()) 
+  while (properties.hasMoreElements())
   {
     property = properties.getNext();
     var values = ds.GetTargets(resource, property, true);
     var value;
-    while (values.hasMoreElements()) 
+    while (values.hasMoreElements())
     {
       value = values.getNext();
       ds.Unassert(resource, property, value, true);
@@ -280,111 +363,63 @@ function isValidRFC822Date(pubDate)
 function dateRescue(dateString)
 {
   // Deal with various kinds of invalid dates
-  if(!isNaN(parseInt(dateString))) 
-  { //It's an integer, so maybe it's a timestamp
+  if(!isNaN(parseInt(dateString)))
+  {
+    // It's an integer, so maybe it's a timestamp
     var d = new Date(parseInt(dateString)*1000);
     var now = new Date();
     var yeardiff = now.getFullYear()-d.getFullYear();
-    debug("Rescue Timestamp date: " + d.toString() + "\nYear diff:" + yeardiff + "\n");
+    debug("Rescue Timestamp date: " + d.toString() + "\nYear diff:"
+        + yeardiff + "\n");
     if((yeardiff >= 0) && (yeardiff<3))
     {
-      //it's quite likely the correct date
+      // It's quite likely the correct date
       return d.toString();
     }
   }
-  if(dateString.search(/^\d\d\d\d/) != -1) //Could be a ISO8601/W3C date
+  if(dateString.search(/^\d\d\d\d/) != -1)
+    //Could be a ISO8601/W3C date
     return W3CToIETFDate(dateString);
- 
+
   // Can't help. Set to current time.
   return (new Date()).toString();
-} 
-
-// Could be a prototype on String, but I don't know the policy on that
-function trimString(s)
-{
-  return(s.replace(/^\s+/,'').replace(/\s+$/,''));
 }
 
 function W3CToIETFDate(dateString) {
-  // Converts a W3C-DTF (subset of ISO 8601) date string to an IETF date string.
-  // W3C-DTF is described in this note: http://www.w3.org/TR/NOTE-datetime
-  // IETF is obtained via the Date object's toUTCString() method.  The object's
-  // toString() method is insufficient because it spells out timezones on Win32
-  // (f.e. "Pacific Standard Time" instead of "PST"), which Mail doesn't grok.
-  // For info, see http://lxr.mozilla.org/mozilla/source/js/src/jsdate.c#1526.
-
-  var parts = dateString.match(/(\d\d\d\d)(-(\d\d))?(-(\d\d))?(T(\d\d):(\d\d)(:(\d\d)(\.(\d+))?)?(Z|([+-])(\d\d):(\d\d))?)?/);
-  debug("date parts: " + parts);
-
-  // Here's an example of a W3C-DTF date string and what .match returns for it.
-  //  date: 2003-05-30T11:18:50.345-08:00
-  //  date.match returns array values:
-  //   0: 2003-05-30T11:18:50-08:00,
-  //   1: 2003,
-  //   2: -05,
-  //   3: 05,
-  //   4: -30,
-  //   5: 30,
-  //   6: T11:18:50-08:00,
-  //   7: 11,
-  //   8: 18,
-  //   9: :50,
-  //   10: 50,
-  //   11: .345,
-  //   12: 345,
-  //   13: -08:00,
-  //   14: -,
-  //   15: 08,
-  //   16: 00
-
-  // Create a Date object from the date parts.  Note that the Date object
-  // apparently can't deal with empty string parameters in lieu of numbers,
-  // so optional values (like hours, minutes, seconds, and milliseconds)
-  // must be forced to be numbers.
-  var date = new Date(parts[1], parts[3]-1, parts[5], parts[7] || 0,
-                      parts[8] || 0, parts[10] || 0, parts[12] || 0);
-
-  // We now have a value that the Date object thinks is in the local timezone
-  // but which actually represents the date/time in the remote timezone
-  // (f.e. the value was "10:00 EST", and we have converted it to "10:00 PST"
-  // instead of "07:00 PST").  We need to correct that.  To do so, we're going
-  // to add the offset between the remote timezone and UTC (to convert the value
-  // to UTC), then add the offset between UTC and the local timezone (to convert
-  // the value to the local timezone).
-
-  // Ironically, W3C-DTF gives us the offset between UTC and the remote timezone
-  // rather than the other way around, while the getTimezoneOffset() method
-  // of a Date object gives us the offset between the local timezone and UTC
-  // rather than the other way around.  Both of these are the additive inverse
-  // (i.e. -x for x) of what we want, so we have to invert them to use them
-  // by multipying by -1
-  // (f.e. if "the offset between UTC and the remote timezone" is -5 hours,
-  // then "the offset between the remote timezone and UTC" is -5*-1 = 5 hours).
-
-  // Note that if the timezone portion of the date/time string is absent
-  // (which violates W3C-DTF, although ISO 8601 allows it), we assume the value
-  // to be in UTC.
-
-  // The offset between the remote timezone and UTC in milliseconds.
-  var remoteToUTCOffset = 0;
-  if (parts[13] && parts[13] != "Z") {
-    var direction = (parts[14] == "+" ? 1 : -1);
-    if (parts[15])
-      remoteToUTCOffset += direction * parts[15] * HOURS_TO_MILLISECONDS;
-    if (parts[16])
-      remoteToUTCOffset += direction * parts[16] * MINUTES_TO_MILLISECONDS;
-  }
-  remoteToUTCOffset = remoteToUTCOffset * -1; // invert it
-  debug("date remote to UTC offset: " + remoteToUTCOffset);
-
-  // The offset between UTC and the local timezone in milliseconds.
-  var UTCToLocalOffset = date.getTimezoneOffset() * MINUTES_TO_MILLISECONDS;
-  UTCToLocalOffset = UTCToLocalOffset * -1; // invert it
-  debug("date UTC to local offset: " + UTCToLocalOffset);
-
-  date.setTime(date.getTime() + remoteToUTCOffset + UTCToLocalOffset);
-
-  debug("date string: " + date.toUTCString());
-
+  var date = ISO8601DateUtils.parse(dateString);
   return date.toUTCString();
 }
+
+function htmlEscape(s)
+{
+  s = s.replace(/&/g, "&amp;");
+  s = s.replace(/>/g, "&gt;");
+  s = s.replace(/</g, "&lt;");
+  s = s.replace(/'/g, "&#39;");
+  s = s.replace(/"/g, "&quot;");
+  return s;
+}
+
+// Returns name as a URN in the 'feeditem' namespace. The
+// returned URN is (or intended to be) RFC2141 compliant. 
+function createURN(name)
+{
+  // The builtin encodeURI provides nearly the exact
+  // encoding functionality required by the RFC.  The
+  // exceptions are that NULL characters should not
+  // appear, and that #, /, ?, &, and ~ should be
+  // escaped.
+  // NULL characters are removed before encoding.
+
+  name = name.replace("\0", "", "g");
+
+  var encoded = encodeURI(name);
+
+  encoded = encoded.replace("#", "%23", "g");
+  encoded = encoded.replace("/", "%2f", "g");
+  encoded = encoded.replace("?", "%3f", "g");
+  encoded = encoded.replace("&", "%26", "g");
+  encoded = encoded.replace("~", "%7e", "g");
+
+  return FZ_ITEM_NS + encoded;
+}
