@@ -1,12 +1,16 @@
-//@line 41 "/home/karma/src/build/build/mail/components/addrbook/content/addressbook.js"
+//@line 42 "/mnt/Srcs/Thunderbird/build/mail/components/addrbook/content/addressbook.js"
+
+// Ensure the activity modules are loaded for this window.
+Components.utils.import("resource://app/modules/activity/activityModules.js");
+
+const nsIAbListener = Components.interfaces.nsIAbListener;
+const kPrefMailAddrBookLastNameFirst = "mail.addr_book.lastnamefirst";
 
 var cvPrefs = 0;
-var addressbook = 0;
 var gSearchTimer = null;
 var gStatusText = null;
 var gQueryURIFormat = null;
 var gSearchInput;
-var gPrintSettings = null;
 var gDirTree;
 var gCardViewBox;
 var gCardViewBoxEmail1;
@@ -77,11 +81,11 @@ var gAddressBookAbListener = {
 };
 
 function OnUnloadAddressBook()
-{  
-  var addrbookSession = Components.classes["@mozilla.org/addressbook/services/session;1"].getService().QueryInterface(Components.interfaces.nsIAddrBookSession);
-  addrbookSession.removeAddressBookListener(gAddressBookAbListener);
+{
+  Components.classes["@mozilla.org/abmanager;1"]
+            .getService(Components.interfaces.nsIAbManager)
+            .removeAddressBookListener(gAddressBookAbListener);
 
-  RemovePrefObservers();
   CloseAbView();
 }
 
@@ -99,64 +103,44 @@ function GetAbViewListener()
   return gAddressBookAbViewListener;
 }
 
-const kPrefMailAddrBookLastNameFirst = "mail.addr_book.lastnamefirst";
-
-var gMailAddrBookLastNameFirstObserver = {
-  observe: function(subject, topic, value) {
-    if (topic == "nsPref:changed" && value == kPrefMailAddrBookLastNameFirst) {
-      UpdateCardView();
-    }
-  }
-}
-
-function AddPrefObservers()
-{
-  var prefService = Components.classes["@mozilla.org/preferences-service;1"]
-                              .getService(Components.interfaces.nsIPrefService);
-  var prefBranch = prefService.getBranch(null).QueryInterface(Components.interfaces.nsIPrefBranch2);
-  prefBranch.addObserver(kPrefMailAddrBookLastNameFirst, gMailAddrBookLastNameFirstObserver, false);
-}
-
-function RemovePrefObservers()
-{
-  var prefService = Components.classes["@mozilla.org/preferences-service;1"]
-                              .getService(Components.interfaces.nsIPrefService);
-  var prefBranch = prefService.getBranch(null).QueryInterface(Components.interfaces.nsIPrefBranch2);
-  prefBranch.removeObserver(kPrefMailAddrBookLastNameFirst, gMailAddrBookLastNameFirstObserver);
-}
-
 // we won't show the window until the onload() handler is finished
 // so we do this trick (suggested by hyatt / blaker)
 function OnLoadAddressBook()
 {
+  // Set a sane starting width/height for all resolutions on new profiles.
+  // Do this before the window loads.
+  if (!document.documentElement.hasAttribute("width"))
+  {
+    // Prefer 860xfull height.
+    let defaultHeight = screen.availHeight;
+    let defaultWidth = (screen.availWidth >= 860) ? 860 : screen.availWidth;
+
+    // On small screens, default to maximized state.
+    if (defaultHeight <= 600)
+      document.documentElement.setAttribute("sizemode", "maximized");
+
+    document.documentElement.setAttribute("width", defaultWidth);
+    document.documentElement.setAttribute("height", defaultHeight);
+    // Make sure we're safe at the left/top edge of screen
+    document.documentElement.setAttribute("screenX", screen.availLeft);
+    document.documentElement.setAttribute("screenY", screen.availTop);
+  }
   setTimeout(delayedOnLoadAddressBook, 0); // when debugging, set this to 5000, so you can see what happens after the window comes up.
 }
 
 function delayedOnLoadAddressBook()
 {
-  gSearchInput = document.getElementById("searchInput");
+  gSearchInput = document.getElementById("peopleSearchInput");
 
-  verifyAccounts(null); 	// this will do migration, if we need to.
-
-  top.addressbook = Components.classes["@mozilla.org/addressbook;1"].createInstance(Components.interfaces.nsIAddressBook);
+  verifyAccounts(null, false);   // this will do migration, if we need to.
 
   InitCommonJS();
 
-  //This migrates the LDAPServer Preferences from 4.x to mozilla format.
-  try {
-      gLDAPPrefsService = Components.classes["@mozilla.org/ldapprefs-service;1"].getService();       
-      gLDAPPrefsService = gLDAPPrefsService.QueryInterface( Components.interfaces.nsILDAPPrefsService);                  
-  } catch (ex) {dump ("ERROR: Cannot get the LDAP service\n" + ex + "\n");}
-
   GetCurrentPrefs();
 
-  AddPrefObservers();
-
   // FIX ME - later we will be able to use onload from the overlay
   OnLoadCardView();
 
-  SetupAbCommandUpdateHandlers();
-
   //workaround - add setTimeout to make sure dynamic overlays get loaded first
   setTimeout('OnLoadDirTree()', 0);
 
@@ -164,26 +148,33 @@ function delayedOnLoadAddressBook()
   if (gPrefs.prefIsLocked("ldap_2.disable_button_add"))
     document.getElementById("addLDAP").setAttribute("disabled", "true");
 
-  // add a listener, so we can switch directories if
-  // the current directory is deleted
-  var addrbookSession = Components.classes["@mozilla.org/addressbook/services/session;1"].getService().QueryInterface(Components.interfaces.nsIAddrBookSession);
-  // this listener cares when a directory (= address book), or a directory item
-  // is/are removed. In the case of directory items, we are only really
-  // interested in mailing list changes and not cards but we have to have both.
-  addrbookSession.addAddressBookListener(
-    gAddressBookAbListener,
-    Components.interfaces.nsIAddrBookSession.directoryRemoved |
-    Components.interfaces.nsIAddrBookSession.directoryItemRemoved);
+  // Add a listener, so we can switch directories if the current directory is
+  // deleted. This listener cares when a directory (= address book), or a
+  // directory item is/are removed. In the case of directory items, we are
+  // only really interested in mailing list changes and not cards but we have
+  // to have both.
+  Components.classes["@mozilla.org/abmanager;1"]
+            .getService(Components.interfaces.nsIAbManager)
+            .addAddressBookListener(gAddressBookAbListener,
+                                    nsIAbListener.directoryRemoved |
+                                    nsIAbListener.directoryItemRemoved);
 
   var dirTree = GetDirTree();
   dirTree.addEventListener("click",DirPaneClick,true);
+  dirTree.controllers.appendController(DirPaneController);
 
   // initialize the customizeDone method on the customizeable toolbar
   var toolbox = document.getElementById("ab-toolbox");
-  toolbox.customizeDone = MailToolboxCustomizeDone;
+  toolbox.customizeDone = function(aEvent) { MailToolboxCustomizeDone(aEvent, "CustomizeABToolbar"); };
 
   var toolbarset = document.getElementById('customToolbars');
   toolbox.toolbarset = toolbarset;
+
+  // Ensure we don't load xul error pages into the main window
+  window.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+        .getInterface(Components.interfaces.nsIWebNavigation)
+        .QueryInterface(Components.interfaces.nsIDocShell)
+        .useErrorPages = false;
 }
 
 function OnLoadDirTree() {
@@ -195,35 +186,35 @@ function OnLoadDirTree() {
 
 function GetCurrentPrefs()
 {
-	// prefs
-	if ( cvPrefs == 0 )
-		cvPrefs = new Object;
+  // prefs
+  if ( cvPrefs == 0 )
+    cvPrefs = new Object;
 
-	cvPrefs.prefs = gPrefs;
-	
-	// check "Show Name As" menu item based on pref
-	var menuitemID;
-	switch (gPrefs.getIntPref("mail.addr_book.lastnamefirst"))
-	{
-		case kFirstNameFirst:
-			menuitemID = 'firstLastCmd';
-			break;
-		case kLastNameFirst:
-			menuitemID = 'lastFirstCmd';
-			break;
-		case kDisplayName:
-		default:
-			menuitemID = 'displayNameCmd';
-			break;
-	}
+  cvPrefs.prefs = gPrefs;
 
-	var menuitem = top.document.getElementById(menuitemID);
-	if ( menuitem )
-		menuitem.setAttribute('checked', 'true');
+  // check "Show Name As" menu item based on pref
+  var menuitemID;
+  switch (gPrefs.getIntPref(kPrefMailAddrBookLastNameFirst))
+  {
+    case kFirstNameFirst:
+      menuitemID = 'firstLastCmd';
+      break;
+    case kLastNameFirst:
+      menuitemID = 'lastFirstCmd';
+      break;
+    case kDisplayName:
+    default:
+      menuitemID = 'displayNameCmd';
+      break;
+  }
 
-  // initialize phonetic 
+  var menuitem = top.document.getElementById(menuitemID);
+  if ( menuitem )
+    menuitem.setAttribute('checked', 'true');
+
+  // initialize phonetic
   var showPhoneticFields =
-        gPrefs.getComplexValue("mail.addr_book.show_phonetic_fields", 
+        gPrefs.getComplexValue("mail.addr_book.show_phonetic_fields",
                                Components.interfaces.nsIPrefLocalizedString).data;
   // show phonetic fields if indicated by the pref
   if (showPhoneticFields == "true")
@@ -235,34 +226,35 @@ function GetCurrentPrefs()
 
 function SetNameColumn(cmd)
 {
-	var prefValue;
-	
-	switch ( cmd )
-	{
-		case 'firstLastCmd':
-			prefValue = kFirstNameFirst;
-			break;
-		case 'lastFirstCmd':
-			prefValue = kLastNameFirst;
-			break;
-		case 'displayNameCmd':
-			prefValue = kDisplayName;
-			break;
-	}
-	
-	cvPrefs.prefs.setIntPref("mail.addr_book.lastnamefirst", prefValue);
+  var prefValue;
+
+  switch ( cmd )
+  {
+    case 'firstLastCmd':
+      prefValue = kFirstNameFirst;
+      break;
+    case 'lastFirstCmd':
+      prefValue = kLastNameFirst;
+      break;
+    case 'displayNameCmd':
+      prefValue = kDisplayName;
+      break;
+  }
+
+  cvPrefs.prefs.setIntPref(kPrefMailAddrBookLastNameFirst, prefValue);
 }
 
-function onFileMenuInit()
+function onOSXFileMenuInit()
 {
-  goUpdateCommand('cmd_printcard'); 
-  goUpdateCommand('cmd_printcardpreview');
+  document.getElementById('menu_osxAddressBook')
+          .setAttribute("checked", AbOSXAddressBookExists());
 }
 
 function CommandUpdate_AddressBook()
 {
   goUpdateCommand('cmd_delete');
   goUpdateCommand('button_delete');
+  goUpdateCommand('cmd_newlist');
 }
 
 function ResultsPaneSelectionChanged()
@@ -278,13 +270,13 @@ function UpdateCardView()
   // either no cards, or more than one card is selected, clear the pane.
   if (cards.length == 1)
     OnClickedCard(cards[0])
-  else 
+  else
     ClearCardViewPane();
 }
 
 function OnClickedCard(card)
-{ 
-  if (card) 
+{
+  if (card)
     DisplayCardViewPane(card);
   else
     ClearCardViewPane();
@@ -295,92 +287,6 @@ function AbClose()
   top.close();
 }
 
-function AbNewLDAPDirectory()
-{
-  window.openDialog("chrome://messenger/content/addressbook/pref-directory-add.xul", 
-                    "", 
-                    "chrome,modal=yes,resizable=no,centerscreen", 
-                    null);
-}
-
-function AbNewAddressBook()
-{
-  var strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].
-      getService(Components.interfaces.nsIStringBundleService);
-  var bundle = strBundleService.createBundle("chrome://messenger/locale/addressbook/addressBook.properties");
-  var dialogTitle = bundle.GetStringFromName('newAddressBookTitle');
-
-  var dialog = window.openDialog(
-    "chrome://messenger/content/addressbook/abAddressBookNameDialog.xul", 
-     "", "chrome,modal=yes,resizable=no,centerscreen", {title: dialogTitle, okCallback:AbOnCreateNewAddressBook});
-}
-
-function AbRenameAddressBook()
-{
-  var selectedABURI = GetSelectedDirectory();
- 
-  // the rdf service
-  var RDF = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);
-
-  // the RDF resource URI for LDAPDirectory will be like: "moz-abmdbdirectory://abook-3.mab"
-  var selectedABDirectory = RDF.GetResource(selectedABURI).QueryInterface(Components.interfaces.nsIAbDirectory);
-
-  var strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].
-      getService(Components.interfaces.nsIStringBundleService);
-  var bundle = strBundleService.createBundle("chrome://messenger/locale/addressbook/addressBook.properties");
-  var dialogTitle = bundle.GetStringFromName('renameAddressBookTitle');
-
-  // you can't rename the PAB or the CAB
-  var canRename = (selectedABURI != kCollectedAddressbookURI && selectedABURI != kPersonalAddressbookURI);
-
-  var dialog = window.openDialog(
-    "chrome://messenger/content/addressbook/abAddressBookNameDialog.xul", 
-     "", "chrome,modal=yes,resizable=no,centerscreen", {title: dialogTitle, canRename: canRename, name: selectedABDirectory.directoryProperties.description,
-      okCallback:AbOnRenameAddressBook});
-}
-
-function AbOnCreateNewAddressBook(aName)
-{
-  var properties = Components.classes["@mozilla.org/addressbook/properties;1"].createInstance(Components.interfaces.nsIAbDirectoryProperties);
-  properties.description = aName;
-  properties.dirType = kPABDirectory;
-  top.addressbook.newAddressBook(properties);
-}
-
-function AbOnRenameAddressBook(aName)
-{
-  // When the UI code for renaming addrbooks (bug #17230) is ready, just 
-  // change 'properties.description' setting below and it should just work.
-  // get select ab
-  var selectedABURI = GetSelectedDirectory();
-  //dump("In AbRenameAddressBook() selectedABURI=" + selectedABURI + "\n");
-
-  // the rdf service
-  var RDF = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);
-  // get the datasource for the addressdirectory
-  var addressbookDS = RDF.GetDataSource("rdf:addressdirectory");
-
-  // moz-abdirectory:// is the RDF root to get all types of addressbooks.
-  var parentDir = RDF.GetResource("moz-abdirectory://").QueryInterface(Components.interfaces.nsIAbDirectory);
-
-  // the RDF resource URI for LDAPDirectory will be like: "moz-abmdbdirectory://abook-3.mab"
-  var selectedABDirectory = RDF.GetResource(selectedABURI).QueryInterface(Components.interfaces.nsIAbDirectory);
-
-  // Copy existing dir type category id and mod time so they won't get reset.
-  var oldProperties = selectedABDirectory.directoryProperties;
-
-  // Create and fill in properties info
-  var properties = Components.classes["@mozilla.org/addressbook/properties;1"].createInstance(Components.interfaces.nsIAbDirectoryProperties);
-  properties.URI = selectedABURI;
-  properties.dirType = oldProperties.dirType;
-  properties.categoryId = oldProperties.categoryId;
-  properties.syncTimeStamp = oldProperties.syncTimeStamp;
-  properties.description = aName;
-
-  // Now do the modification.
-  addressbook.modifyAddressBook(addressbookDS, parentDir, selectedABDirectory, properties);
-}
-
 function AbPrintCardInternal(doPrintPreview, msgType)
 {
   var selectedItems = GetSelectedAbCards();
@@ -389,7 +295,6 @@ function AbPrintCardInternal(doPrintPreview, msgType)
   if (!numSelected)
     return;
 
-  var addressbook = Components.classes["@mozilla.org/addressbook;1"].createInstance(Components.interfaces.nsIAddressBook);
   var uri = GetSelectedDirectory();
   if (!uri)
     return;
@@ -412,16 +317,11 @@ function AbPrintCardInternal(doPrintPreview, msgType)
      }
   }
 
-  if (!gPrintSettings)
-  {
-    gPrintSettings = PrintUtils.getPrintSettings();
-  }
-
   printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xul",
                                          "",
                                          "chrome,dialog=no,all",
-                                          totalCard, selectionArray, statusFeedback, 
-                                          gPrintSettings, doPrintPreview, msgType);
+                                          totalCard, selectionArray, statusFeedback,
+                                          doPrintPreview, msgType);
 
   return;
 }
@@ -438,20 +338,18 @@ function AbPrintPreviewCard()
 
 function CreatePrintCardUrl(card)
 {
-  var url = "data:application/xml;base64," + card.convertToBase64EncodedXML();
-  return url;
+  return "data:application/xml;base64," + card.translateTo("base64xml");
 }
 
 function AbPrintAddressBookInternal(doPrintPreview, msgType)
 {
-  var addressbook = Components.classes["@mozilla.org/addressbook;1"].createInstance(Components.interfaces.nsIAddressBook);
   var uri = GetSelectedDirectory();
   if (!uri)
     return;
 
   var statusFeedback;
-	statusFeedback = Components.classes["@mozilla.org/messenger/statusfeedback;1"].createInstance();
-	statusFeedback = statusFeedback.QueryInterface(Components.interfaces.nsIMsgStatusFeedback);
+  statusFeedback = Components.classes["@mozilla.org/messenger/statusfeedback;1"].createInstance();
+  statusFeedback = statusFeedback.QueryInterface(Components.interfaces.nsIMsgStatusFeedback);
 
   /*
     turn "moz-abmdbdirectory://abook.mab" into
@@ -461,16 +359,12 @@ function AbPrintAddressBookInternal(doPrintPreview, msgType)
   var abURIArr = uri.split("://");
   var printUrl = "addbook://" + abURIArr[0] + "/" + abURIArr[1] + "?action=print"
 
-  if (!gPrintSettings) {
-    gPrintSettings = PrintUtils.getPrintSettings();
-  }
+  printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xul",
+                    "",
+                    "chrome,dialog=no,all",
+                    1, [printUrl], statusFeedback, doPrintPreview, msgType);
 
-	printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xul",
-										"",
-										"chrome,dialog=no,all",
-										1, [printUrl], statusFeedback, gPrintSettings, doPrintPreview, msgType);
-
-	return;
+  return;
 }
 
 function AbPrintAddressBook()
@@ -488,9 +382,11 @@ function AbExport()
   try {
     var selectedABURI = GetSelectedDirectory();
     if (!selectedABURI) return;
-    
+
     var directory = GetDirectoryFromURI(selectedABURI);
-    addressbook.exportAddressBook(window, directory);
+    Components.classes["@mozilla.org/abmanager;1"]
+              .getService(Components.interfaces.nsIAbManager)
+              .exportAddressBook(window, directory);
   }
   catch (ex) {
     var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
@@ -510,75 +406,12 @@ function AbExport()
       }
 
       promptService.alert(window,
-        gAddressBookBundle.getString("failedToExportTitle"), 
+        gAddressBookBundle.getString("failedToExportTitle"),
         message);
     }
   }
 }
 
-function AbDeleteDirectory()
-{
-  var selectedABURI = GetSelectedDirectory();
-  if (!selectedABURI)
-    return;
-
-  var parentArray = Components.classes["@mozilla.org/supports-array;1"].createInstance(Components.interfaces.nsISupportsArray);
-  if (!parentArray) 
-    return; 
-
-  var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
- 
-  var parentRow = GetParentRow(dirTree, dirTree.currentIndex);
-  var parentId = (parentRow == -1) ? "moz-abdirectory://" : dirTree.builderView.getResourceAtIndex(parentRow).Value;
-  var parentDir = GetDirectoryFromURI(parentId);
-  parentArray.AppendElement(parentDir);
-    
-  var directory = GetDirectoryFromURI(selectedABURI);
-  var confirmDeleteMessage;
-  var clearPrefsRequired = false;
-
-  if (directory.isMailList)
-    confirmDeleteMessage = gAddressBookBundle.getString("confirmDeleteMailingList");
-  else {
-    // Check if this address book is being used for collection
-    if (gPrefs.getCharPref("mail.collect_addressbook") == selectedABURI &&
-        (gPrefs.getBoolPref("mail.collect_email_address_outgoing") ||
-         gPrefs.getBoolPref("mail.collect_email_address_newsgroup"))) {
-      var brandShortName = document.getElementById("bundle_brand").getString("brandShortName");
-
-      confirmDeleteMessage = gAddressBookBundle.getFormattedString("confirmDeleteCollectionAddressbook", [brandShortName]);
-      clearPrefsRequired = true;
-    }
-    else {
-      confirmDeleteMessage = gAddressBookBundle.getString("confirmDeleteAddressbook");
-    }
-  }
-
-  if (!promptService.confirm(window,
-                             gAddressBookBundle.getString(
-                                                directory.isMailList ?
-                                                "confirmDeleteMailingListTitle" :
-                                                "confirmDeleteAddressbookTitle"),
-                             confirmDeleteMessage))
-    return;
-
-  // First clear all the prefs if required
-  if (clearPrefsRequired) {
-    gPrefs.setBoolPref("mail.collect_email_address_outgoing", false);
-    gPrefs.setBoolPref("mail.collect_email_address_newsgroup", false);
-
-    // Also reset the displayed value so that we don't get a blank item in the
-    // prefs dialog if it gets enabled.
-    gPrefs.setCharPref("mail.collect_addressbook", kPersonalAddressbookURI);
-  }
-
-  var resourceArray = Components.classes["@mozilla.org/supports-array;1"].createInstance(Components.interfaces.nsISupportsArray);
-  var selectedABResource = GetDirectoryFromURI(selectedABURI).QueryInterface(Components.interfaces.nsIRDFResource);
-  resourceArray.AppendElement(selectedABResource);
-
-  top.addressbook.deleteAddressBooks(dirTree.database, parentArray, resourceArray);
-}
-
 function SetStatusText(total)
 {
   if (!gStatusText)
@@ -594,12 +427,12 @@ function SetStatusText(total)
       {
         if (total == 1)
           statusText = gAddressBookBundle.getString("matchFound");
-        else  
+        else
           statusText = gAddressBookBundle.getFormattedString("matchesFound", [total]);
       }
     }
     else
-      statusText = gAddressBookBundle.getFormattedString("totalCardStatus", [gAbView.directory.dirName, total]);   
+      statusText = gAddressBookBundle.getFormattedString("totalContactStatus", [gAbView.directory.dirName, total]);
 
     gStatusText.setAttribute("label", statusText);
   }
@@ -630,28 +463,25 @@ function onAdvancedAbSearch()
   if (existingSearchWindow)
     existingSearchWindow.focus();
   else
-    window.openDialog("chrome://messenger/content/ABSearchDialog.xul", "", 
-                      "chrome,resizable,status,centerscreen,dialog=no", 
+    window.openDialog("chrome://messenger/content/ABSearchDialog.xul", "",
+                      "chrome,resizable,status,centerscreen,dialog=no",
                       {directory: selectedABURI});
 }
 
 function onEnterInSearchBar()
 {
-  ClearCardViewPane();  
+  ClearCardViewPane();
 
   if (!gQueryURIFormat)
-    gQueryURIFormat = gPrefs.getComplexValue("mail.addr_book.quicksearchquery.format", 
+    gQueryURIFormat = gPrefs.getComplexValue("mail.addr_book.quicksearchquery.format",
                                               Components.interfaces.nsIPrefLocalizedString).data;
 
   var searchURI = GetSelectedDirectory();
   if (!searchURI) return;
 
-  var sortColumn = gAbView.sortColumn;
-  var sortDirection = gAbView.sortDirection;
-
   /*
    XXX todo, handle the case where the LDAP url
-   already has a query, like 
+   already has a query, like
    moz-abldapdirectory://nsdirectory.netscape.com:389/ou=People,dc=netscape,dc=com?(or(Department,=,Applications))
   */
   if (gSearchInput.value != "") {
@@ -660,10 +490,10 @@ function onEnterInSearchBar()
     searchURI += gQueryURIFormat.replace(/@V/g, encodeURIComponent(gSearchInput.value));
   }
 
-  SetAbView(searchURI, gSearchInput.value != "", sortColumn, sortDirection);
-  
-  // XXX todo 
-  // this works for synchronous searches of local addressbooks, 
+  SetAbView(searchURI);
+
+  // XXX todo
+  // this works for synchronous searches of local addressbooks,
   // but not for LDAP searches
   SelectFirstCard();
 }
@@ -675,7 +505,6 @@ function SwitchPaneFocus(event)
   var cardViewBoxEmail1 = GetCardViewBoxEmail1();
   var searchBox         = document.getElementById('search-container');
   var dirTree           = GetDirTree();
-  var searchInput       = GetSearchInput();
 
   if (event && event.shiftKey)
   {
@@ -688,9 +517,9 @@ function SwitchPaneFocus(event)
       if(cardViewBoxEmail1)
         cardViewBoxEmail1.focus();
       else
-        cardViewBox.focus();    
+        cardViewBox.focus();
     }
-    else 
+    else
       gAbResultsTree.focus();
   }
   else
@@ -702,12 +531,12 @@ function SwitchPaneFocus(event)
       if(cardViewBoxEmail1)
         cardViewBoxEmail1.focus();
       else
-        cardViewBox.focus();    
+        cardViewBox.focus();
     }
     else if (focusedElement != dirTree && !IsDirPaneCollapsed())
       dirTree.focus();
     else if (searchBox)
-      searchInput.focus();
+      gSearchInput.focus();
     else
       gAbResultsTree.focus();
   }
@@ -718,7 +547,7 @@ function WhichPaneHasFocus()
   var cardViewBox       = GetCardViewBox();
   var searchBox         = document.getElementById('search-container');
   var dirTree           = GetDirTree();
-    
+
   var currentNode = top.document.commandDispatcher.focusedElement;
   while (currentNode)
   {
@@ -743,13 +572,6 @@ function GetDirTree()
   return gDirTree;
 }
 
-function GetSearchInput()
-{
-  if (!gSearchInput)
-    gSearchInput = document.getElementById('searchInput');
-  return gSearchInput;
-}
-
 function GetCardViewBox()
 {
   if (!gCardViewBox)
@@ -791,9 +613,11 @@ function IsCardViewAndAbResultsPaneSplitterCollapsed()
 
 function LaunchUrl(url)
 {
-  var messenger = Components.classes["@mozilla.org/messenger;1"].createInstance(Components.interfaces.nsIMessenger);
-  messenger.SetWindow(window,null);
-  messenger.OpenURL(url);
+  // Doesn't matter if this bit fails, window.location contains its own prompts
+  try {
+    window.location = url;
+  }
+  catch (ex) {}
 }
 
 function AbIMSelected()
@@ -805,7 +629,7 @@ function AbIMSelected()
   var screennameCount = 0;
 
   for (var i=0;i<count;i++) {
-    var screenname = cards[i].aimScreenName;
+    var screenname = cards[i].getProperty("_AimScreenName", "");
     if (screenname) {
       if (screennameCount == 0)
         screennames = screenname;
@@ -830,3 +654,49 @@ function AbIMSelected()
   LaunchUrl(url);
 }
 
+function getMailToolbox()
+{
+  return document.getElementById("ab-toolbox");
+}
+
+const kOSXDirectoryURI = "moz-abosxdirectory:///";
+const kOSXPrefBase = "ldap_2.servers.osx";
+
+function AbOSXAddressBookExists()
+{
+  var prefSvc = Components.classes["@mozilla.org/preferences-service;1"]
+                          .getService(Components.interfaces.nsIPrefBranch);
+
+  // I hate doing it this way - until we redo how we manage address books
+  // I can't think of a better way though.
+
+  // See if the pref exists, if so, then we need to delete the address book
+  var uriPresent = false;
+  var position = 1;
+  try {
+    uriPresent = prefSvc.getCharPref(kOSXPrefBase + ".uri") == kOSXDirectoryURI;
+  }
+  catch (e) { }
+
+  try {
+    position = prefSvc.getIntPref(kOSXPrefBase + ".position");
+  }
+  catch (e) { }
+
+  // Address book exists if the uri is correct and the position is not zero.
+  return uriPresent && position != 0;
+}
+
+function AbShowHideOSXAddressBook()
+{
+  var abMgr = Components.classes["@mozilla.org/abmanager;1"] 
+                        .getService(Components.interfaces.nsIAbManager);
+
+  if (AbOSXAddressBookExists())
+    abMgr.deleteAddressBook(kOSXDirectoryURI);
+  else {
+    abMgr.newAddressBook(
+      gAddressBookBundle.getString(kOSXPrefBase + ".description"),
+      kOSXDirectoryURI, 3, kOSXPrefBase);
+  }
+}
