@@ -1,14 +1,15 @@
-//@line 39 "/home/karma/src/build/build/mail/base/content/mail-offline.js"
+//@line 39 "/mnt/Srcs/Thunderbird/build/mail/base/content/mail-offline.js"
 
 var MailOfflineMgr = {
   offlineManager: null,
   offlineBundle: null,
-  
+
   init: function()
   {
     var os = Components.classes["@mozilla.org/observer-service;1"]
               .getService(Components.interfaces.nsIObserverService);
     os.addObserver(this, "network:offline-status-changed", false);
+
     this.offlineManager = Components.classes["@mozilla.org/messenger/offline-manager;1"]                 
                         .getService(Components.interfaces.nsIMsgOfflineManager);
     this.offlineBundle = document.getElementById("bundle_offlinePrompts");
@@ -16,23 +17,23 @@ var MailOfflineMgr = {
     // initialize our offline state UI
     this.updateOfflineUI(!this.isOnline());
   },
-  
+
   uninit: function()
   {
     var os = Components.classes["@mozilla.org/observer-service;1"]
               .getService(Components.interfaces.nsIObserverService);
     os.removeObserver(this, "network:offline-status-changed");
   },
-  
-  /** 
+
+  /**
    * @return true if we are online
    */
-  isOnline: function()
-  {
-    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
-                           .getService(Components.interfaces.nsIIOService);
-    return (!ioService.offline);
-  },
+   isOnline: function()
+   {
+      var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                             .getService(Components.interfaces.nsIIOService);
+      return (!ioService.offline);
+   },
 
   /**
    * Toggles the online / offline state, initiated by the user. Depending on user settings
@@ -52,14 +53,14 @@ var MailOfflineMgr = {
       var sendUnsentMessages = (prefSendUnsentMessages == 0 && this.haveUnsentMessages() 
                                 && this.confirmSendUnsentMessages()) || prefSendUnsentMessages == 1;
       this.offlineManager.goOnline(sendUnsentMessages, true /* playbackOfflineImapOperations */, msgWindow);
+
       // resume managing offline status now that we are going back online.
-      ioService.manageOfflineStatus = gPrefBranch.getBoolPref("offline.autoDetect");       
+      ioService.manageOfflineStatus = gPrefBranch.getBoolPref("offline.autoDetect");      
     }
     else // going offline
     {
       // Stop automatic management of the offline status since the user as decided to go offline.
       ioService.manageOfflineStatus = false;
-      
       var prefDownloadMessages = gPrefBranch.getIntPref("offline.download.download_messages");
       // 0 == Ask, 1 == Always Download, 2 == Never Download
       var downloadForOfflineUse = (prefDownloadMessages == 0 && this.confirmDownloadMessagesForOfflineUse())
@@ -67,48 +68,21 @@ var MailOfflineMgr = {
       this.offlineManager.synchronizeForOffline(downloadForOfflineUse, downloadForOfflineUse, false, true, msgWindow);
     }
   },
-  
+
   observe: function (aSubject, aTopic, aState)
   {
     if (aTopic == "network:offline-status-changed")
       this.mailOfflineStateChanged(aState == "offline");
   },
-  
-  /** 
+
+  /**
    * @return true if there are unsent messages
    */
   haveUnsentMessages: function()
-{
-  try
   {
-    var am = Components.classes["@mozilla.org/messenger/account-manager;1"]
-                 .getService(Components.interfaces.nsIMsgAccountManager);
-    var msgSendlater = Components.classes["@mozilla.org/messengercompose/sendlater;1"]
-                 .getService(Components.interfaces.nsIMsgSendLater);
-    var identitiesCount, allIdentities, currentIdentity, numMessages, msgFolder;
-
-      if (am) 
-      { 
-      allIdentities = am.allIdentities;
-      identitiesCount = allIdentities.Count();
-        for (var i = 0; i < identitiesCount; i++) 
-        {
-        currentIdentity = allIdentities.QueryElementAt(i, Components.interfaces.nsIMsgIdentity);
-        msgFolder = msgSendlater.getUnsentMessagesFolder(currentIdentity);
-          if(msgFolder) 
-          {
-          // if true, descends into all subfolders 
-          numMessages = msgFolder.getTotalMessages(false);
-            if(numMessages > 0) 
-              return true;
-        }
-      } 
-    }
-  }
-  catch(ex) {
-  }
-    
-  return false;
+    return Components.classes["@mozilla.org/messengercompose/sendlater;1"]
+                     .getService(Components.interfaces.nsIMsgSendLater)
+                     .hasUnsentMessages();
   },
 
   /**
@@ -116,27 +90,27 @@ var MailOfflineMgr = {
    * account.
    */
   openOfflineAccountSettings: function()
-{
+  {
     window.parent.MsgAccountManager('am-offline.xul');
   },
 
-  /** 
+  /**
    * Prompt the user about going online to send unsent messages, and then send them
    * if appropriate. Puts the app back into online mode.
-   * 
+   *
    * @param aMsgWindow the msg window to be used when going online
-   */   
+   */
   goOnlineToSendMessages: function(aMsgWindow)
   {
     const nsIPS = Components.interfaces.nsIPromptService;
     var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(nsIPS);
     var goOnlineToSendMsgs = promptService.confirm(window, 
                                                    this.offlineBundle.getString('sendMessagesOfflineWindowTitle1'), 
-                                                   this.offlineBundle.getString('sendMessagesOfflineLabel'));
+                                                   this.offlineBundle.getString('sendMessagesOfflineLabel1'));
     if (goOnlineToSendMsgs)
       this.offlineManager.goOnline(true /* send unsent messages*/, false, aMsgWindow);
   },
-  
+
   /**
    * Prompts the user to confirm sending of unsent messages. This is different from 
    * goOnlineToSendMessages which involves going online to send unsent messages.
@@ -150,19 +124,19 @@ var MailOfflineMgr = {
     var alwaysAsk = {value: true};
     var sendUnsentMessages = promptService.confirmEx(window, 
                                                      this.offlineBundle.getString('sendMessagesWindowTitle1'), 
-                                                     this.offlineBundle.getString('sendMessagesLabel1'),
+                                                     this.offlineBundle.getString('sendMessagesLabel2'),
                                                      nsIPS.STD_YES_NO_BUTTONS,
                                                      null, null, null,
                                                      this.offlineBundle.getString('sendMessagesCheckboxLabel1'), 
                                                      alwaysAsk) == 0 ? true : false;
-                             
+
     // if the user changed the ask me setting then update the global pref based on their yes / no answer
     if (!alwaysAsk.value)
       gPrefBranch.setIntPref("offline.send.unsent_messages", sendUnsentMessages ? 1 : 2);
     return sendUnsentMessages;
   },
-   
-  /** 
+
+  /**
    * Should we send unsent messages? Based on the value of
    * offline.send.unsent_messages, this method may prompt the user.
    * @return true if we should send unsent messages
@@ -188,7 +162,7 @@ var MailOfflineMgr = {
    * May update the value of offline.download.download_messages
    *
    * @return true if the user wants to download messages for offline use.
-   */   
+   */
   confirmDownloadMessagesForOfflineUse: function()
   {
     const nsIPS = Components.interfaces.nsIPromptService;
@@ -201,13 +175,13 @@ var MailOfflineMgr = {
                                                    null, null, null,
                                                    this.offlineBundle.getString('downloadMessagesCheckboxLabel1'), 
                                                    alwaysAsk) == 0 ? true : false;
-                             
+
     // if the user changed the ask me setting then update the global pref based on their yes / no answer
     if (!alwaysAsk.value)
       gPrefBranch.setIntPref("offline.download.download_messages", downloadMessages ? 1 : 2);
     return downloadMessages;      
   },
-  
+
   /** 
    *  Get New Mail When Offline
    *  Prompts the user about going online in order to download new messages. 
@@ -227,7 +201,7 @@ var MailOfflineMgr = {
                                    false /* playbackOfflineImapOperations */, msgWindow);
     return goOnline;
   },
-   
+
   /** 
    * Private helper method to update the state of the Offline menu item
    * and the offline status bar indicator
@@ -237,23 +211,22 @@ var MailOfflineMgr = {
     document.getElementById('goOfflineMenuItem').setAttribute("checked", aIsOffline);
     var statusBarPanel = document.getElementById('offline-status');
     if (aIsOffline)
-{
+    {
       statusBarPanel.setAttribute("offline", "true");
       statusBarPanel.setAttribute("tooltiptext", this.offlineBundle.getString("offlineTooltip"));
-}
+    }
     else
-{
+    {
       statusBarPanel.removeAttribute("offline");
       statusBarPanel.setAttribute("tooltiptext", this.offlineBundle.getString("onlineTooltip"));
-}
+    }    
   },   
 
   /**
    * private helper method called whenever we detect a change to the offline state
    */ 
   mailOfflineStateChanged: function (aGoingOffline)
-{
-    gFolderJustSwitched = true;
+  {
     this.updateOfflineUI(aGoingOffline);
   }
 };
