@@ -1,4 +1,4 @@
-//@line 38 "/home/kojima/Thunderbird/build/mail/components/preferences/advanced.js"
+//@line 38 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
 
 var gAdvancedPane = {
   mPane: null,
@@ -7,20 +7,48 @@ var gAdvancedPane = {
   init: function ()
   {
     this.mPane = document.getElementById("paneAdvanced");
-    this.updateMarkAsReadTextbox(false);
+    this.updateMarkAsReadOptions(document.getElementById("automaticallyMarkAsRead").checked);
 
     if ("arguments" in window && window.arguments[1] && document.getElementById(window.arguments[1]))
       document.getElementById("advancedPrefs").selectedTab = document.getElementById(window.arguments[1]);
     else 
-    {    
+    {
       var preference = document.getElementById("mail.preferences.advanced.selectedTabIndex");
       if (preference.value)
         document.getElementById("advancedPrefs").selectedIndex = preference.value;
     }
-
+//@line 57 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
     this.updateAppUpdateItems();
     this.updateAutoItems();
-    this.updateModeItems();   
+    this.updateModeItems();
+//@line 61 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
+
+    // Search integration -- check whether we should hide or disable integration
+    let hideSearchUI = false;
+    let disableSearchUI = false;
+    Components.utils.import("resource://app/modules/SearchIntegration.js");
+    if (SearchIntegration)
+    {
+      if (SearchIntegration.osVersionTooLow)
+        hideSearchUI = true;
+      else if (SearchIntegration.osComponentsNotRunning)
+        disableSearchUI = true;
+    }
+    else
+    {
+      hideSearchUI = true;
+    }
+
+    if (hideSearchUI)
+    {
+      document.getElementById("searchIntegrationContainer").hidden = true;
+    }
+    else if (disableSearchUI)
+    {
+      let searchCheckbox = document.getElementById("searchIntegration");
+      searchCheckbox.checked = false;
+      document.getElementById("searchintegration.enable").disabled = true;
+    }
 
     this.mInitialized = true;
   },
@@ -34,6 +62,49 @@ var gAdvancedPane = {
     }
   },
 
+//@line 102 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
+  /**
+   * Checks whether Thunderbird is currently registered with the operating
+   * system as the default app for mail, rss and news.  If Thunderbird is not
+   * currently the default app, the user is given the option of making it the
+   * default for each type; otherwise, the user is informed that Thunderbird is
+   * already the default.
+   */
+  checkDefaultNow: function (aAppType)
+  {
+    var nsIShellService = Components.interfaces.nsIShellService;
+    var shellSvc;
+    try {
+      shellSvc = Components.classes["@mozilla.org/mail/shell-service;1"]
+                           .getService(nsIShellService);
+    } catch (ex) { return; }
+
+    // If we are already the default for all the handled types, alert the user.
+    if (shellSvc.isDefaultClient(false, nsIShellService.MAIL |
+                                        nsIShellService.NEWS |
+                                        nsIShellService.RSS))
+    {
+      var brandBundle = document.getElementById("bundleBrand");
+      var preferencesBundle = document.getElementById("bundlePreferences");
+      var brandShortName = brandBundle.getString("brandShortName");
+      var promptTitle = preferencesBundle.getString("alreadyDefaultClientTitle");
+      var psvc = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+                           .getService(Components.interfaces.nsIPromptService);
+
+      var promptMessage = preferencesBundle.getFormattedString("alreadyDefault",
+                                                               [brandShortName]);
+      psvc.alert(window, promptTitle, promptMessage);
+    }
+    else
+    {
+      // otherwise, bring up the default client dialog
+      window.openDialog("chrome://messenger/content/systemIntegrationDialog.xul",
+                        "SystemIntegration",
+                        "modal,centerscreen,chrome,resizable=no");
+    }
+  },
+//@line 143 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
+
   showConfigEdit: function()
   {
     document.documentElement.openWindow("Preferences:ConfigManager",
@@ -41,6 +112,48 @@ var gAdvancedPane = {
                                         "", null);
   },
 
+  // NETWORK TAB
+
+  /*
+   * Preferences:
+   *
+   * browser.cache.disk.capacity
+   * - the size of the browser cache in KB
+   */
+
+  /**
+   * Converts the cache size from units of KB to units of MB and returns that
+   * value.
+   */
+  readCacheSize: function ()
+  {
+    var preference = document.getElementById("browser.cache.disk.capacity");
+    return preference.value / 1024;
+  },
+
+  /**
+   * Converts the cache size as specified in UI (in MB) to KB and returns that
+   * value.
+   */
+  writeCacheSize: function ()
+  {
+    var cacheSize = document.getElementById("cacheSize");
+    var intValue = parseInt(cacheSize.value, 10);
+    return isNaN(intValue) ? 0 : intValue * 1024;
+  },
+
+  /**
+   * Clears the cache.
+   */
+  clearCache: function ()
+  {
+    var cacheService = Components.classes["@mozilla.org/network/cache-service;1"]
+                                 .getService(Components.interfaces.nsICacheService);
+    try {
+      cacheService.evictEntries(Components.interfaces.nsICache.STORE_ANYWHERE);
+    } catch(ex) {}
+  },
+
   updateButtons: function (aButtonID, aPreferenceID)
   {
     var button = document.getElementById(aButtonID);
@@ -76,8 +189,9 @@ var gAdvancedPane = {
    *             ii  f       t/f       true
    *             iii 0/1/2   f         false
    *             iii 0/1/2   t         true   
-   * 
+   *
    */
+//@line 231 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
   updateAppUpdateItems: function () 
   {
     var aus = 
@@ -89,15 +203,15 @@ var gAdvancedPane = {
 
     enableAppUpdate.disabled = !aus.canUpdate || enabledPref.locked;
   },
-  
+
   updateAutoItems: function () 
   {
     var enabledPref = document.getElementById("app.update.enabled");
     var autoPref = document.getElementById("app.update.auto");
-    
+
     var updateModeLabel = document.getElementById("updateModeLabel");
     var updateMode = document.getElementById("updateMode");
-    
+
     var disable = enabledPref.locked || !enabledPref.value ||
                   autoPref.locked;
     updateModeLabel.disabled = updateMode.disabled = disable;
@@ -108,26 +222,14 @@ var gAdvancedPane = {
     var enabledPref = document.getElementById("app.update.enabled");
     var autoPref = document.getElementById("app.update.auto");
     var modePref = document.getElementById("app.update.mode");
-    
+
     var warnIncompatible = document.getElementById("warnIncompatible");
-    
+
     var disable = enabledPref.locked || !enabledPref.value || autoPref.locked ||
                   !autoPref.value || modePref.locked;
     warnIncompatible.disabled = disable;
   },
 
-  /**
-   * The Extensions checkbox and button are disabled only if the enable Addon
-   * update preference is locked. 
-   */
-  updateAddonUpdateUI: function ()
-  {
-    var enabledPref = document.getElementById("extensions.update.enabled");
-    var enableAddonUpdate = document.getElementById("enableAddonUpdate");
-
-    enableAddonUpdate.disabled = enabledPref.locked;
-  },  
-
   /**
    * app.update.mode is a three state integer preference, and we have to 
    * express all three values in a single checkbox:
@@ -146,29 +248,52 @@ var gAdvancedPane = {
     gAdvancedPane._modePreference = doNotWarn ? preference.value : 1;
     return doNotWarn;
   },
-  
+
   addonWarnSyncTo: function ()
   {
     var warnIncompatible = document.getElementById("warnIncompatible");
     return !warnIncompatible.checked ? 0 : gAdvancedPane._modePreference;
   },
-   
+
   showUpdates: function ()
   {
     var prompter = Components.classes["@mozilla.org/updates/update-prompt;1"]
                              .createInstance(Components.interfaces.nsIUpdatePrompt);
     prompter.showUpdateHistory(window);
   },
+//@line 301 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/advanced.js"
 
-  updateMarkAsReadTextbox: function(aFocusTextBox) 
+  /**
+   * The Extensions checkbox and button are disabled only if the enable Addon
+   * update preference is locked. 
+   */
+  updateAddonUpdateUI: function ()
   {
-    var textbox = document.getElementById('markAsReadDelay'); 
-    textbox.disabled = !document.getElementById('markAsRead').checked;
+    var enabledPref = document.getElementById("extensions.update.enabled");
+    var enableAddonUpdate = document.getElementById("enableAddonUpdate");
+
+    enableAddonUpdate.disabled = enabledPref.locked;
+  },  
+
+  updateMarkAsReadOptions: function(enableRadioGroup)
+  {
+    document.getElementById('markAsReadAutoPreferences').disabled = !enableRadioGroup;
+    // ... and the extras!
+    document.getElementById('markAsReadDelay').disabled =
+      (!enableRadioGroup ||
+       !document.getElementById("mailnews.mark_message_read.delay").value);
+    document.getElementById('secondsLabel').disabled = !enableRadioGroup;
+  },
+
+  updateMarkAsReadTextbox: function(aFocusTextBox)
+  {
+    var textbox = document.getElementById('markAsReadDelay');
+    textbox.disabled = !document.getElementById('markAsReadAfterDelay').selected;
     if (!textbox.disabled && aFocusTextBox)
         textbox.focus();
   },
-  
-  /** 
+
+  /**
    * open the return receipts configuration dialog 
    */
   showReturnReceipts: function()
@@ -176,7 +301,7 @@ var gAdvancedPane = {
     document.documentElement.openSubDialog("chrome://messenger/content/preferences/receipts.xul",
                                            "", null);
   },  
-  
+
   /** 
    * open the connections dialog 
    */
@@ -186,8 +311,8 @@ var gAdvancedPane = {
             .openSubDialog("chrome://messenger/content/preferences/connection.xul",
                            "", null);
   },
-  
-  /** 
+
+  /**
    * open the offline settings dialog
    */
   showOffline: function()
@@ -196,25 +321,25 @@ var gAdvancedPane = {
             .openSubDialog("chrome://messenger/content/preferences/offline.xul",
                            "", null);  
   },
-  
+
   showCertificates: function ()
   {
     document.documentElement.openWindow("mozilla:certmanager", "chrome://pippki/content/certManager.xul",
                                         "width=600,height=400", null);
   },
-  
+
   showCRLs: function ()
   {
-    document.documentElement.openWindow("Mozilla:CRLManager", "chrome://pippki/content/crlManager.xul",
+    document.documentElement.openWindow("mozilla:crlmanager", "chrome://pippki/content/crlManager.xul",
                                         "width=600,height=400", null);
   },
-  
+
   showOCSP: function ()
   {
     document.documentElement.openSubDialog("chrome://mozapps/content/preferences/ocsp.xul",
                                            "", null);
   },
-  
+
   showSecurityDevices: function ()
   {
     document.documentElement.openWindow("mozilla:devicemanager", "chrome://pippki/content/device_manager.xul",
