@@ -1,4 +1,4 @@
-//@line 38 "/home/karma/src/build/build/mail/components/preferences/general.js"
+//@line 38 "/mnt/Srcs/Thunderbird/build/mail/components/preferences/general.js"
 
 var gGeneralPane = {
   mPane: null,
@@ -6,56 +6,11 @@ var gGeneralPane = {
 
   init: function ()
   {
-    this.mPane = document.getElementById("paneGeneral"); 
-    this.startPageCheck();
+    this.mPane = document.getElementById("paneGeneral");
     
     this.updatePlaySound();
   },
-
-//@line 52 "/home/karma/src/build/build/mail/components/preferences/general.js"
-  /**
-   * Checks whether Thunderbird is currently registered with the operating
-   * system as the default app for mail, rss and news.  If Thunderbird is not currently the
-   * default app, the user is given the option of making it the default for each type;
-   * otherwise, the user is informed that Thunderbird is already the default.
-   */
-  checkDefaultNow: function (aAppType) 
-  {   
-    var nsIShellService = Components.interfaces.nsIShellService;
-    var shellSvc;
-    try {
-      shellSvc = Components.classes["@mozilla.org/mail/shell-service;1"].getService(nsIShellService);
-    } catch (ex) { return; }
     
-    // if we are already the default for all the types we handle, then alert the user.
-    if (shellSvc.isDefaultClient(false, nsIShellService.MAIL | nsIShellService.NEWS | nsIShellService.RSS))
-    {
-      var brandBundle = document.getElementById("bundleBrand");
-      var shellBundle = document.getElementById("bundleShell");
-      var brandShortName = brandBundle.getString("brandShortName");
-      var promptTitle = shellBundle.getString("alreadyDefaultClientTitle");
-      var promptMessage;
-      const IPS = Components.interfaces.nsIPromptService;
-      var psvc = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
-                           .getService(IPS);
-
-        promptMessage = shellBundle.getFormattedString("alreadyDefault", [brandShortName]);
-        psvc.alert(window, promptTitle, promptMessage);
-    }
-    else
-  {
-      // otherwise, bring up the default client dialog
-      window.openDialog("chrome://messenger/content/defaultClientDialog.xul", "Default Client", 
-                        "modal,centerscreen,chrome,resizable=no");
-    }
-  },
-//@line 89 "/home/karma/src/build/build/mail/components/preferences/general.js"
-
-  startPageCheck: function() 
-  {
-    document.getElementById("mailnewsStartPageUrl").disabled = !document.getElementById("mailnewsStartPageEnabled").checked;
-  },
-  
   /**
    * Restores the default start page as the user's start page
    */
@@ -63,8 +18,6 @@ var gGeneralPane = {
   {
     var startPage = document.getElementById("mailnews.start_page.url");
     startPage.value = startPage.defaultValue;
-    if (startPage.hasUserValue)
-      startPage.reset();
   },
   
   /**
@@ -92,14 +45,14 @@ var gGeneralPane = {
                                getService(Components.interfaces.nsIURLFormatter);
     return formatter.formatURL(this.mStartPageUrl) == startPage.value ? this.mStartPageUrl : startPage.value;         
   },
-
+  
   customizeMailAlert: function()
   {
     document.documentElement
             .openSubDialog("chrome://messenger/content/preferences/notifications.xul",
-                           "", null);
+                            "", null);
   },
-
+  
   convertURLToLocalFile: function(aFileURL)
   {
     // convert the file url into a nsILocalFile
@@ -139,7 +92,7 @@ var gGeneralPane = {
     {
       var ioService = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
       sound.play(ioService.newURI(soundLocation, null, null));
-  }
+    }
   },
   
   browseForSoundFile: function ()
@@ -151,7 +104,7 @@ var gGeneralPane = {
     // as the initial path in the dialog.
     var localFile = this.convertURLToLocalFile(document.getElementById('soundUrlLocation').value);
     if (localFile)
-      fp.displayDirectory = localFile;
+      fp.displayDirectory = localFile.parent;
 
     // XXX todo, persist the last sound directory and pass it in
     fp.init(window, document.getElementById("bundlePreferences").getString("soundFilePickerTitle"), nsIFilePicker.modeOpen);
@@ -176,4 +129,24 @@ var gGeneralPane = {
     document.getElementById('browseForSound').disabled = soundsDisabled || soundTypeEl.value != 1;
     document.getElementById('playSound').disabled = soundsDisabled || soundTypeEl.value != 1; 
   },
+
+  /**
+   * Displays the Add-ons Manager.
+   */
+  showAddonsMgr: function ()
+  {
+    const EMTYPE = "Extension:Manager";
+    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
+                       .getService(Components.interfaces.nsIWindowMediator);
+    var theEM = wm.getMostRecentWindow(EMTYPE);
+    if (theEM) {
+      theEM.focus();
+      theEM.showView("extensions");
+      return;
+    }
+
+    const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
+    const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
+    window.openDialog(EMURL, "", EMFEATURES, "extensions");
+  }
 };
