@@ -66,7 +66,6 @@ pref("editor.table.maintain_structure", true);
 pref("editor.prettyprint", true);
 
 pref("editor.throbber.url","chrome://editor-region/locale/region.properties");
-pref("editor.spellcheckers.url","chrome://editor-region/locale/region.properties");
 
 pref("editor.toolbars.showbutton.new", true);
 pref("editor.toolbars.showbutton.open", true);
@@ -98,13 +97,6 @@ pref("editor.toolbars.showbutton.absolutePosition", true);
 pref("editor.toolbars.showbutton.decreaseZIndex", true);
 pref("editor.toolbars.showbutton.increaseZIndex", true);
 
-pref("editor.auto_save",                    false);
-pref("editor.auto_save_delay",              10);    // minutes
-pref("editor.use_html_editor",              0);
-pref("editor.html_editor",                  "");
-pref("editor.use_image_editor",             0);
-pref("editor.image_editor",                 "");
-
 pref("editor.history.url_maximum", 10);
 
 pref("editor.publish.",                      "");
@@ -129,9 +121,13 @@ pref("editor.always_show_publish_dialog",    false);
  */
 //pref("editor.encode_entity",                 "html");
 
-//@line 134 "/home/karma/src/build/build/editor/ui/composer.js"
+//@line 126 "/mnt/Srcs/Thunderbird/build/editor/ui/composer.js"
 pref("editor.disable_spell_checker", false);
 pref("editor.dont_lock_spell_files", true);
-//@line 138 "/home/karma/src/build/build/editor/ui/composer.js"
+//@line 130 "/mnt/Srcs/Thunderbird/build/editor/ui/composer.js"
 
 pref("editor.CR_creates_new_p",      false);
+
+// Pasting images from the clipboard, order of encoding preference: 
+// JPEG-PNG-GIF=0, PNG-JPEG-GIF=1, GIF-JPEG-PNG=2
+pref("clipboard.paste_image_type", 1);
